@@ -584,7 +584,7 @@ class ArgParse():
         sbp.add_argument(
                 "--evpr_source",
                 help='Specify source for Gff file protein evidence ex \
-                      "blastx", default=undefined',
+                      "blastx, miniprot", default=undefined',
                 default="undefined",
                 type=str
         )
@@ -767,7 +767,7 @@ class ArgParse():
         sbp.add_argument(
                 "--evpr_source",
                 help='Specify source for Gff file protein evidence ex \
-                     "blastx, diamond, exonerate", default=undefined',
+                     "blastx, diamond, exonerate, miniprot", default=undefined',
                 default="undefined",
                 type=str
         )
