@@ -16,6 +16,17 @@ from ingenannot.entities.gene import Gene
 
 class Utils(object):
 
+
+    @staticmethod
+    def get_aed_from_attributes(genes):
+
+        logging.info("Retrieving aed annotations")
+
+        for g in genes:
+            for tr in g.lTranscripts:
+                tr.set_evidence_aed_info_from_attributes()
+
+
     @staticmethod
     def get_sources_from_fof(fof):
         """get sources from fof"""
@@ -171,6 +182,8 @@ class Utils(object):
             for i,r in enumerate(results):
                 r_clusters = r.get()
                 merged_clusters.extend(r_clusters)
+            pool.close()
+            pool.join()
         else:
             for ref in references:
                 clusters_ref = [x for x in clusters if x.seqid == ref]
@@ -260,6 +273,8 @@ class Utils(object):
             for i,r in enumerate(results):
                 r_clusters = r.get()
                 merged_clusters.extend(r_clusters)
+            pool.close()
+            pool.join()
         else:
             for ref in references:
                 clusters_ref = [x for x in clusters if x.seqid == ref]
@@ -475,6 +490,8 @@ class Utils(object):
                   'T':'A',
                   'C':'G',
                   'G':'C',
+                  'N':'N',
+                  'n':'n',
                   '-':'-'}
         Rev = []
         for base in seq[::-1]:
@@ -645,5 +662,68 @@ class Utils(object):
     def natural_sort(ls):
     
         ls.sort(key=Utils.natural_keys)
-    
- 
+
+    @staticmethod
+    def rank_transcripts(transcripts, gaeval):
+        """double sort tr and pr, compare list, when
+           discrepency, use distances"""
+
+        l_sorted = []
+        l_tr_rank = sorted(transcripts, key=lambda tr: (min(tr.best_tr_evidence[1],tr.best_lg_evidence[1]), tr.best_bx_evidence[1]))
+        l_pr_rank = sorted(transcripts, key=lambda tr: (tr.best_bx_evidence[1], min(tr.best_tr_evidence[1],tr.best_lg_evidence[1])))
+        for idx in range(0,len(transcripts)):
+            tr_to_remove = None
+            if l_tr_rank[0] == l_pr_rank[0]:
+                tr_to_remove = l_tr_rank[0]
+            elif l_tr_rank[0].best_bx_evidence[1] == l_pr_rank[0].best_bx_evidence[1]:
+                tr_to_remove = l_tr_rank[0]
+            else:
+                if gaeval:
+                    if l_pr_rank[0].gaeval_infos['int'] > l_tr_rank[0].gaeval_infos['int']:
+                        tr_to_remove = l_pr_rank[0]
+                    else:
+                        tr_to_remove = l_tr_rank[0]
+                else:
+                    tr_delta = l_pr_rank[0].best_tr_evidence[1] - l_tr_rank[0].best_tr_evidence[1]
+                    # add stronger weigth on protein distance 
+#                    pr_delta = (l_tr_rank[0].best_bx_evidence[1] - l_pr_rank[0].best_bx_evidence[1]) * 1.5
+                    pr_delta = l_tr_rank[0].best_bx_evidence[1] - l_pr_rank[0].best_bx_evidence[1]
+
+                    # To validate BUG ? order
+                    if tr_delta >= pr_delta:
+                        tr_to_remove = l_tr_rank[0]
+                    else:
+                        tr_to_remove = l_pr_rank[0]
+            l_sorted.append(tr_to_remove)
+            l_tr_rank.remove(tr_to_remove)
+            l_pr_rank.remove(tr_to_remove)
+
+        return l_sorted
+
+    @staticmethod
+    def aed_strand_filter_transcripts(transcripts):
+
+        conflict_list = []
+        tr_dict = {}
+        references = set([tr.seqid for tr in transcripts])
+        for ref in references:
+            ref_tr = sorted([tr for tr in transcripts if tr.seqid == ref], key=lambda x: x.get_min_cds_start())
+            for i,tr in enumerate(ref_tr[:-1]):
+                    tr_dict[(tr.id,tr.source)] = tr
+                    for tr2 in ref_tr[i+1:]:
+                      if tr.is_feature_spanning(tr2):
+                        if tr.overlap_cds_with_other_transcript_cds(tr2):
+                            conflict_list.append(((tr.id,tr.source), (tr2.id,tr2.source)))
+
+            # add last tr in dict
+            tr_dict[(ref_tr[-1].id,ref_tr[-1].source)] = ref_tr[-1]
+
+        logging.info("{} potential conflicts to resolved".format(len(conflict_list)))
+
+        list_to_remove = []
+        for cf in conflict_list:
+            l = Utils.rank_transcripts([tr_dict[cf[0]],tr_dict[cf[1]]],False)
+            if l[0] not in list_to_remove:
+                list_to_remove.append(l[1])
+
+        return list_to_remove
