@@ -119,6 +119,8 @@ class AnnotEditDistance():
         builder = GeneBuilder('gtf')
         if evtype == "pr":
             builder = GeneBuilder('gff3-blastx')
+            if source == "miniprot":
+                builder = GeneBuilder('gff3-miniprot')
 
         for gene in genes:
             features = []
@@ -133,7 +135,10 @@ class AnnotEditDistance():
                 max_end.append(int(row.split("\t")[4]))
             for row in tbx.fetch(gene.seqid, min(min_start), max(max_end)):
                 if evtype == "pr":
-                    features.append(GFF3Reader.convertRowToFeature(str(row)))
+                    if source == "miniprot":
+                        features.append(GFF3Reader.convertRowToFeature(str(row), downgraded=True))
+                    else:
+                        features.append(GFF3Reader.convertRowToFeature(str(row)))
                 else:
                     features.append(GTFReader.convertRowToFeature(str(row)))
             if len(features) > 0:
