@@ -138,11 +138,37 @@ class GFF3BlastxBuilderFeature(GFF3BuilderFeature):
 #        print(len(features))
         return features
 
+class GFF3MiniprotBuilderFeature(GFF3BuilderFeature):
+
+    def convert_features(self, features):
+        '''convert features from miniprot gff to feat with expected values'''
+
+        new_features = []
+        idx = 0
+        for feat in features:
+            if feat.type == 'mRNA':
+                feat.attributes['Parent'] = ['gene-{}'.format(feat.id)]
+                idx=0
+            if feat.type == 'CDS':
+                idx += 1
+                feat.id = 'CDS-{}.{}'.format(feat.attributes['Parent'][0],idx)
+                feat.attributes['ID'] = [feat.id]
+                # add exon missing in output
+                feat_cp = copy.deepcopy(feat)
+                feat_cp.type = 'exon'
+                feat_cp.id = 'exon-{}.{}'.format(feat.attributes['Parent'][0],idx)
+                feat_cp.attributes['ID'] = [feat_cp.id]
+                new_features.append(feat_cp)
+        features.extend(new_features)
+        return features
+
+
 class GeneBuilder(object):
 
     __builders = {'gff3':GFF3BuilderFeature,
                   'gtf':GTFBuilderFeature,
-                  'gff3-blastx':GFF3BlastxBuilderFeature}
+                  'gff3-blastx':GFF3BlastxBuilderFeature,
+                  'gff3-miniprot':GFF3MiniprotBuilderFeature}
 
     def __init__(self, fmt):
 
@@ -155,7 +181,7 @@ class GeneBuilder(object):
         transcripts = {}
         exons = {}
         cds = {}
-        if self.fmt == 'gff3-blastx':
+        if self.fmt in ['gff3-blastx','gff3-miniprot']:
             features = self.builder.convert_features(features)
         #idx = 0
         for feat in features:
