@@ -73,7 +73,7 @@ class GFF3Reader():
                     dAttributes[tag] = val.split(",")
         return dAttributes
 
-    def read(self):
+    def read(self, downgraded=False):
         """Iterator on feature"""
 
         currentLine = None
@@ -89,7 +89,7 @@ class GFF3Reader():
                     print(line)
                     raise Exception("Error GFF format line:{}".format(idx))
 
-                id = GFF3Reader._getFeatureTagValue('ID',m.group(9))
+                id = GFF3Reader._getFeatureTagValue('ID',m.group(9),downgraded)
                 dAttributes = GFF3Reader._stringToDict(m.group(9))
                 score = None
                 try:
@@ -107,13 +107,13 @@ class GFF3Reader():
                 yield f
 
     @staticmethod
-    def convertRowToFeature(row, idx=None):
+    def convertRowToFeature(row, idx=None, downgraded=False):
 
         m = re.search(r"^\s*(\S+)\s+(\S+)\s+(\S+)\s+(\d+)\s+(\d+)\s+(\S+)\s+([+-.])\s+(\S+)\s+(\S.*)$", row)
         if m == None:
             raise Exception("Error GFF format line:{}".format(idx))
 
-        id = GFF3Reader._getFeatureTagValue('ID',m.group(9))
+        id = GFF3Reader._getFeatureTagValue('ID',m.group(9),downgraded=downgraded)
         dAttributes = GFF3Reader._stringToDict(m.group(9))
         score = None
         try:
@@ -132,11 +132,13 @@ class GFF3Reader():
 
 
     @staticmethod
-    def _getFeatureTagValue(tag, line):
+    def _getFeatureTagValue(tag, line, downgraded=False):
         """Return the fist value of the tag property"""
         m = re.search(r".*{mytag}=([^;]*);{{0,1}}.*".format(mytag = tag),line)
         if m:
             return m.group(1).split(',')[0]
+        elif downgraded:
+            return None 
         else:
             raise Exception('Cannot find tag {} in string \'{}\''.format(tag, line))
 
@@ -236,7 +238,7 @@ class GTFReader():
 
         return f
 
-    def read(self):
+    def read(self, downgraded=False):
         """Iterator on feature"""
 
         currentLine = None
@@ -345,10 +347,10 @@ class GFFReader():
             return "gff2"
 
 
-    def read(self):
+    def read(self, downgraded=False):
         """return dedicated reader feature generator"""
 
-        yield from self.reader.read()
+        yield from self.reader.read(downgraded=downgraded)
 
     @staticmethod
     def convertRowToFeature(row, idx=None):
